library(car)
library(ggplot2)

gdata <- read.table("gdiv_rdata.txt", header=T)

contrasts(gdata$habitat)=contr.sum(4)
contrasts(gdata$guild)=contr.sum(7)

#plantdiv curvature assessment
m1 <- lm(insectdiv ~ site + habitat + guild + plantdiv + I(plantdiv^2), data=gdata)
summary(m1)
#plantdiv curvature irrelevant

#collinearity test
#site is perfectly collinear with one of the other variables - vif will not run
m2 <- lm(insectdiv ~ habitat + guild + plantdiv, data=gdata)
vif(m2)
#plantdiv and habitat variables are collinear

#model simplification
#variables with all interaction terms except collinear interaction (habitat:plantdiv)
m3 <- lm(insectdiv ~ habitat + guild + plantdiv + habitat:guild + guild:plantdiv, data=gdata)
summary(m3)
#habitat:guild most complex and least significant - remove
m4 <- lm(insectdiv ~ habitat + guild + plantdiv + guild:plantdiv, data=gdata)
anova(m3,m4)
#try removing guild:plantdiv
m5 <- lm(insectdiv ~ habitat + guild + plantdiv, data=gdata)
anova(m4,m5)
#removal of guild:plantdiv interaction term causes significant (p-value) loss of explanatory power
#final model is m4
Anova(m4, type=2) #type 2 - interaction term gives same p-value for all types, type 2 is more accurate for other terms in unbalanced models

#plots
#interaction plot of guild and plantdiv against insectdiv
interaction.plot(gdata$plantdiv, gdata$guild, gdata$insectdiv, col=c("red","blue","forestgreen","black","purple","orange","brown"), lty="solid")
p <- ggplot(gdata, (aes(x=plantdiv, y=insectdiv, color=guild, shape=guild))) + theme_classic()
p + geom_point() + geom_smooth(method=lm, se=FALSE, fullrange=TRUE)
#habitat vs insect div
plot(gdata$habitat, gdata$insectdiv)
#plant div vs insect div
plot(gdata$plantdiv, gdata$insectdiv)
abline(lm(insectdiv ~ plantdiv, data=gdata))

#given the interaction term is significant, examine each guild's linear regression separately
#phytophages:
phyto <- gdata[which(gdata$guild=='phyto'),]
plot(phyto$plantdiv, phyto$insectdiv, pch=19)
abline(lm(phyto$insectdiv ~ phyto$plantdiv), col="red")
phytom <- lm(insectdiv ~ plantdiv, data=phyto)
summary(phytom)
#pollinators:
nectar <- gdata[which(gdata$guild=='nectar'),]
plot(nectar$plantdiv, nectar$insectdiv, pch=19)
abline(lm(nectar$insectdiv ~ nectar$plantdiv), col="red")
nectarm <- lm(insectdiv ~ plantdiv, data=nectar)
summary(nectarm)
#fungivores:
fungi <- gdata[which(gdata$guild=='fungi'),]
plot(fungi$plantdiv, fungi$insectdiv, pch=19)
abline(lm(fungi$insectdiv ~ fungi$plantdiv), col="red")
fungim <- lm(insectdiv ~ plantdiv, data=fungi)
summary(fungim)
#parasitoids:
paras <- gdata[which(gdata$guild=='paras'),]
plot(paras$plantdiv, paras$insectdiv, pch=19)
abline(lm(paras$insectdiv ~ paras$plantdiv), col="red")
parasm <- lm(insectdiv ~ plantdiv, data=paras)
summary(parasm)
#predators:
pred <- gdata[which(gdata$guild=='pred'),]
plot(pred$plantdiv, pred$insectdiv, pch=19)
abline(lm(pred$insectdiv ~ pred$plantdiv), col="red")
predm <- lm(insectdiv ~ plantdiv, data=pred)
summary(predm)
#haematophages:
haem <- gdata[which(gdata$guild=='haem'),]
plot(haem$plantdiv, haem$insectdiv, pch=19)
abline(lm(haem$insectdiv ~ haem$plantdiv), col="red")
haemm <- lm(insectdiv ~ plantdiv, data=haem)
summary(haemm)
#detritivores
det <- gdata[which(gdata$guild=='det'),]
plot(det$plantdiv, det$insectdiv, pch=19)
abline(lm(det$insectdiv ~ det$plantdiv), col="red")
detm <- lm(insectdiv ~ plantdiv, data=det)
summary(detm)
